/*
** Module   : MenuItemWidget.java
** Abstract : server side menu item widget implementation
**
** Copyright (c) 2014-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------------------Description-----------------------------
** 001 VIG 20141118          Created initial version.
*/
package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * This class represents menu-item widget.
 */
@LegacyResource(resource = LegacyResource.MENU_ITEM)
public class MenuItemWidget
extends GenericWidget<MenuItemConfig>
{
   /**
    * Hot key for menu calling. Set by adding '&' to label.
    * The key is the first character after '&' or first 
    * character of the whole label if there is no '&' in it.
    */
   private Character mnemonic;
   
   /**
    * Default constructor for dynamic menu-items  
    */
   public MenuItemWidget()
   {
      super(true, new MenuItemConfig());
   }

   /**
    * Default constructor for static menu-item
    * 
    * @param    dynamic
    *           Flag indicating if this is a static or dynamic resource.
    */
   public MenuItemWidget(String name, String label)
   {
      super(false, new MenuItemConfig());
      name(name);
      setLabel(label);
   }

   /**
    * Sets the label text, parsing mnemonic.
    * 
    * TODO: find out what is going on with undocumented feature of very long label
    * See parent's javadoc.
    * 
    * @param    label
    *           The new label text.
    */
   @Override
   public void setLabel(String label)
   {
      config.setDynamicLabel(label);
      
      int idx = label.indexOf('&');
      
      // TODO find out what mnemonic will be if '&' is the last symbol.
      if (idx < 0 || idx == label.length() - 1) 
      {
         mnemonic = label.charAt(0);
      }
      else
      {
         mnemonic = label.charAt(idx + 1);
      }
      
      // TODO It seems that pushScreenDefinition is not needed here 
      //      because the menu-item is not in a frame. Not sure because
      //      a popup menu can be owned by widget, for example, by button.
   }

   /**
    * Get MENU-ITEM mnemonic key.
    * 
    * @return  Mnemonic character.
    *          At some moment of dynamic menu-item construction it can be null. 
    */
   public Character getMnemonic()
   {
      return mnemonic;
   }
   
   
}